@@ -84,9 +84,11 @@ def init(config_file, session_file):
     executed with other commands.
     """
     cfg = load_config(config_file)
+    operators_cfg = cfg.operators_config
 
-    modules = cosmic_ray.modules.find_modules(Path(cfg["module-path"]))
-    modules = cosmic_ray.modules.filter_paths(modules, cfg.get("exclude-modules", ()))
+    module_paths = [Path(cfg["module-path"])] if isinstance(cfg["module-path"], str) else map(Path, cfg["module-path"])
+    modules = cosmic_ray.modules.find_modules(module_paths)
+    modules = cosmic_ray.modules.filter_paths(modules, cfg.get("excluded-modules", ()))
 
     if log.isEnabledFor(logging.INFO):
         log.info("Modules discovered:")
@@ -97,7 +99,7 @@ def init(config_file, session_file):
             log.info(" - %s: %s", directory, ", ".join(sorted(files)))
 
     with use_db(session_file) as database:
-        cosmic_ray.commands.init(modules, database)
+        cosmic_ray.commands.init(modules, database, operators_cfg)
 
     sys.exit(ExitCode.OK)
 
