@@ -87,6 +87,18 @@ class ConfigDict(dict):
         name = self.distributor_name
         return self["distributor"].get(name, ConfigDict())
 
+    @property
+    def operators_config(self):
+        """The configuration for specified operators.
+        
+        This is a dict mapping operator names to dicts which represent keyword-arguments
+        for parameterizing an operator. Each keyword arg dict is a single parameterization
+        of the operator, and each parameterized operator will be executed once for each
+        parameterization.
+        """
+        return self.get("operators", {})
+
+
 
 @contextmanager
 def _config_stream(filename):
