@@ -4,21 +4,24 @@ import glob
 from pathlib import Path
 
 
-def find_modules(module_path):
+def find_modules(module_paths):
     """Find all modules in the module (possibly package) represented by ``module_path``.
 
     Args:
-        module_path: A pathlib.Path to a Python package or module.
+        module_paths: A list of pathlib.Path to Python packages or modules.
 
     Returns:
         An iterable of paths Python modules (i.e. \\*py files).
     """
-    if module_path.is_file():
-        if module_path.suffix == ".py":
-            yield module_path
-    elif module_path.is_dir():
-        pyfiles = glob.glob("{}/**/*.py".format(module_path), recursive=True)
-        yield from (Path(pyfile) for pyfile in pyfiles)
+    for module_path in module_paths:
+        if not module_path.exists():
+            raise FileNotFoundError("Could not find module path {}".format(module_path))
+        if module_path.is_file():
+            if module_path.suffix == ".py":
+                yield module_path
+        elif module_path.is_dir():
+            pyfiles = glob.glob("{}/**/*.py".format(module_path), recursive=True)
+            yield from (Path(pyfile) for pyfile in pyfiles)
 
 
 def filter_paths(paths, excluded_paths):
