@@ -1,10 +1,9 @@
 "Implementation of the exception-replacement operator."
 
+from cosmic_ray.exceptions import CosmicRayTestingException
 from parso.python.tree import Name, PythonNode
 
-from cosmic_ray.exceptions import CosmicRayTestingException
-
-from .operator import Operator
+from .operator import Example, Operator
 
 
 class ExceptionReplacer(Operator):
@@ -32,24 +31,30 @@ class ExceptionReplacer(Operator):
 
         atom = node.children[1]
         test_list = atom.children[1]
+        if isinstance(test_list, Name):
+            return (test_list,)
         return test_list.children[::2]
 
     @classmethod
     def examples(cls):
         return (
-            (
+            Example(
                 "try: raise OSError\nexcept OSError: pass",
                 "try: raise OSError\nexcept {}: pass".format(CosmicRayTestingException.__name__),
             ),
-            (
+            Example(
+                "try: raise OSError\nexcept (OSError): pass",
+                "try: raise OSError\nexcept ({}): pass".format(CosmicRayTestingException.__name__),
+            ),
+            Example(
                 "try: raise OSError\nexcept (OSError, ValueError): pass",
                 "try: raise OSError\nexcept (OSError, {}): pass".format(CosmicRayTestingException.__name__),
-                1,
+                occurrence=1,
             ),
-            (
+            Example(
                 "try: raise OSError\nexcept (OSError, ValueError, KeyError): pass",
                 "try: raise OSError\nexcept (OSError, {}, KeyError): pass".format(CosmicRayTestingException.__name__),
-                1,
+                occurrence=1,
             ),
-            ("try: pass\nexcept: pass", "try: pass\nexcept: pass"),
+            Example("try: pass\nexcept: pass", "try: pass\nexcept: pass"),
         )
