@@ -1,6 +1,6 @@
 "Implementation of the no-op operator."
 
-from .operator import Operator
+from .operator import Example, Operator
 
 
 class NoOp(Operator):
@@ -20,7 +20,7 @@ class NoOp(Operator):
     @classmethod
     def examples(cls):
         return (
-            ('@foo\ndef bar(): pass', '@foo\ndef bar(): pass'),
-            ('def bar(): pass', 'def bar(): pass'),
-            ('1 + 1', '1 + 1'),
+            Example("@foo\ndef bar(): pass", "@foo\ndef bar(): pass"),
+            Example("def bar(): pass", "def bar(): pass"),
+            Example("1 + 1", "1 + 1"),
         )
