@@ -4,7 +4,7 @@
 import parso
 
 from ..ast import is_number
-from .operator import Operator
+from .operator import Example, Operator
 
 # List of offsets that we apply to numbers in the AST. Each index into the list
 # corresponds to single mutation.
@@ -25,19 +25,19 @@ class NumberReplacer(Operator):
     def mutate(self, node, index):
         """Modify the numeric value on `node`."""
 
-        assert index < len(OFFSETS), 'received count with no associated offset'
+        assert index < len(OFFSETS), "received count with no associated offset"
         assert isinstance(node, parso.python.tree.Number)
 
         val = eval(node.value) + OFFSETS[index]  # pylint: disable=W0123
-        return parso.python.tree.Number(' ' + str(val), node.start_pos)
+        return parso.python.tree.Number(" " + str(val), node.start_pos)
 
     @classmethod
     def examples(cls):
         return (
-            ('x = 1', 'x = 2'),
-            ('x = 1', 'x = 0', 1),
-            ('x = 4.2', 'x = 5.2'),
-            ('x = 4.2', 'x = 3.2', 1),
-            ('x = 1j', 'x = (1+1j)'),
-            ('x = 1j', 'x = (-1+1j)', 1),
+            Example("x = 1", "x = 2"),
+            Example("x = 1", "x = 0", occurrence=1),
+            Example("x = 4.2", "x = 5.2"),
+            Example("x = 4.2", "x = 3.2", occurrence=1),
+            Example("x = 1j", "x = (1+1j)"),
+            Example("x = 1j", "x = (-1+1j)", occurrence=1),
         )
