@@ -2,7 +2,7 @@
 
 from parso.python.tree import Decorator
 
-from .operator import Operator
+from .operator import Example, Operator
 
 
 class RemoveDecorator(Operator):
@@ -19,8 +19,8 @@ class RemoveDecorator(Operator):
     @classmethod
     def examples(cls):
         return (
-            ('@foo\ndef bar(): pass', 'def bar(): pass'),
-            ('@first\n@second\ndef bar(): pass', '@second\ndef bar(): pass'),
-            ('@first\n@second\ndef bar(): pass', '@first\ndef bar(): pass', 1),
-            ('@first\n@second\n@third\ndef bar(): pass', '@first\n@third\ndef bar(): pass', 1),
+            Example("@foo\ndef bar(): pass", "def bar(): pass"),
+            Example("@first\n@second\ndef bar(): pass", "@second\ndef bar(): pass"),
+            Example("@first\n@second\ndef bar(): pass", "@first\ndef bar(): pass", occurrence=1),
+            Example("@first\n@second\n@third\ndef bar(): pass", "@first\n@third\ndef bar(): pass", occurrence=1),
         )
